VttFile class

VTT file class model

path the path to the xml file, and items the list of vtt cue objects.

Constructors

VttFile(List<VttFileCue> items, {required String path})
const
VttFile.fromXmlFile(XmlFile xmlFile)

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<VttFileCue>
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited