VttFileCue class

VTT file cue model

st the start time as hh:mm:ss.xxx (xxx milliseconds) et the end time as hh:mm:ss.xxx sub the sub title

Constructors

VttFileCue({String? st, String? et, String? sub})
const
VttFileCue.fromXmlFileCue(XmlFileCue xmlFileCue)
factory

Properties

et String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
st String?
final
sub String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited